@@ -1,6 +1,11 @@
 pub use crate::traits::signature::DigitalSignatureTrait;
 pub use crate::seed::*;
 
+// FALCON1024
 pub use crate::falcon::falcon1024::{Falcon1024Keypair,Falcon1024Signature};
+
+// BLS
 pub use crate::bls::bls_signature::{BLSKeypair,VerifyBLSSignature};
-pub use crate::schnorr::schnorr::SchnorrKeypair;
\ No newline at end of file
+
+// Schnorr
+pub use crate::schnorr::schnorr::{SchnorrSignature,SchnorrKeypair};
\ No newline at end of file
