@@ -7,6 +7,7 @@ use rand::prelude::*;
 use rand_chacha::ChaCha20Rng;
 use crate::seed::*;
 use crate::os_random::*;
+use bs58::*;
 
 use serde::{Serialize,Deserialize};
 
@@ -31,7 +32,7 @@ pub struct SchnorrSignature {
 }
 
 impl SchnorrSignature {
-    /// Verifies signature
+    /// Verifies signatures by using the context, message, public key, and signature.
     pub fn verify(&self) -> bool {
         // Construct Public Key
         let publickey = PublicKey::from_bytes(&self.pk).expect("Failed To Construct Schnorr Public Key In Verification");
@@ -51,13 +52,16 @@ impl SchnorrSignature {
     }
     /// # From Encoding
     /// 
-    /// Converts Public Key (Hex), Signature (Base64), context (bytes), message (bytes) to Schnorr Signature
+    /// Converts Public Key (Hex), Signature (Base58), context (bytes), message (bytes) to Schnorr Signature
     pub fn from_encoding<T: AsRef<str>>(pk: T, signature: T, context: &[u8], message: &[u8]) -> Self {
         let mut pk_output: [u8;PUBLIC_KEY_LENGTH] = [0u8;PUBLIC_KEY_LENGTH];
         let mut signature_output: [u8;SIGNATURE_LENGTH] = [0u8;SIGNATURE_LENGTH];
         
         let public_key_decoded = hex::decode(pk.as_ref()).expect("Failed To Decode Public Key From Hex For Schnorr Signatures");
-        let signature = base64::decode(signature.as_ref()).expect("Failed To Decode Signature From Base64 For Schnorr Signatures");
+        // BASE64
+        //let signature = base64::decode(signature.as_ref()).expect("Failed To Decode Signature From Base64 For Schnorr Signatures");
+        let signature = bs58::decode(signature.as_ref()).into_vec().expect("Failed To Decode From Base58 To Signature For Schnorr Signatures");
+
 
         let mut i: usize = 0;
 
@@ -80,20 +84,28 @@ impl SchnorrSignature {
             message: message.to_vec(),
         }
     }
+    /// Return public key as hexadecimal
     pub fn return_pk_as_hex(&self) -> String {
         return hex::encode_upper(self.pk)
     }
+    /// Return signature as base64
     pub fn return_signature_as_base64(&self) -> String {
         return base64::encode(self.signature)
     }
+    /// Return signature as base58
+    pub fn return_signature_as_base58(&self) -> String {
+        return bs58::encode(self.signature).into_string()
+    }
+    /// Return context as vector of bytes
     pub fn return_context(&self) -> Vec<u8> {
         return self.context.clone()
     }
+    /// Return message as vector of bytes
     pub fn return_message(&self) -> Vec<u8> {
         return self.message.clone()
     }
     pub fn return_all(&self) -> (String,String,Vec<u8>,Vec<u8>) {
-        return (hex::encode_upper(self.pk),base64::encode(self.signature),self.context.clone(),self.message.clone())
+        return (hex::encode_upper(self.pk),bs58::encode(self.signature).into_string(),self.context.clone(),self.message.clone())
     }
 }
 
@@ -111,6 +123,7 @@ impl SchnorrKeypair {
         }
 
     }
+    /// Signs message using a random context generated by a random number generator
     pub fn sign_with_rng(&self, message: &[u8]) -> SchnorrSignature {
         let keypair = self.construct();
 
@@ -125,7 +138,8 @@ impl SchnorrKeypair {
             message: message.clone().to_vec(),
         }
     }
-    pub fn simple_sign(&self, context: &[u8], message: &[u8]) -> SchnorrSignature {
+    /// Signs a message using the context and message as inputs.
+    pub fn sign(&self, context: &[u8], message: &[u8]) -> SchnorrSignature {
         let keypair = self.construct();
         let sig = keypair.sign_simple_doublecheck(context,message).expect("Failed To Sign");
         
@@ -181,7 +195,7 @@ fn schnorr_generation_from_seed(){
     let seed = phrase.derive_seed("Password1234", Language::English);
 
     let keypair = SchnorrKeypair::new(&seed.as_bytes());
-    let signature = keypair.simple_sign(b"This is the Context",b"This message is being signed");
+    let signature = keypair.sign(b"This is the Context",b"This message is being signed");
     let is_valid = signature.verify();
 
     let mut signature2 = keypair.sign_with_rng(b"Hello World");
